## $Id: browser.py 12065 2014-11-26 18:23:23Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for products offered by the company.
"""

import sys
import grok
import pytz
from urllib import urlencode
from datetime import datetime
from zope.event import notify
from zope.i18n import translate
from zope.catalog.interfaces import ICatalog
from zope.component import queryUtility, getUtility, createObject
from zope.schema.interfaces import ConstraintNotSatisfied, RequiredMissing
from zope.formlib.textwidgets import BytesDisplayWidget
from zope.security import checkPermission
from waeup.ikoba.interfaces import MessageFactory as _
from waeup.ikoba.interfaces import (
    IContactForm, IObjectHistory, IIkobaObject, IIkobaUtils)
from waeup.ikoba.browser.layout import (
    IkobaPage, IkobaEditFormPage, IkobaAddFormPage, IkobaDisplayFormPage,
    IkobaForm, NullValidator, jsaction, action, UtilityView)
from waeup.ikoba.widgets.datewidget import (
    FriendlyDateWidget, FriendlyDateDisplayWidget,
    FriendlyDatetimeDisplayWidget)
from waeup.ikoba.browser.breadcrumbs import Breadcrumb

from waeup.ikoba.products.interfaces import (
    IProductsContainer, IProduct)

grok.context(IIkobaObject) # Make IKofaObject the default context
grok.templatedir('browser_templates')


class ProductsBreadcrumb(Breadcrumb):
    """A breadcrumb for the customers container.
    """
    grok.context(IProductsContainer)
    title = _('Products')


class ProductBreadcrumb(Breadcrumb):
    """A breadcrumb for the customer container.
    """
    grok.context(IProduct)

    def title(self):
        return self.context.title


class ProductsContainerPage(IkobaDisplayFormPage):
    """The standard view for product containers.
    """
    grok.context(IProductsContainer)
    grok.name('index')
    grok.require('waeup.Public')
    #grok.template('containerpage')
    pnav = 1
    label = _('Products')


class ProductsContainerManageFormPage(IkobaEditFormPage):
    """The manage page for customer containers.
    """
    grok.context(IProductsContainer)
    grok.name('manage')
    grok.require('waeup.manageProducts')
    #grok.template('containermanagepage')
    pnav = 1
    label = _('Manage product section')


class ProductAddFormPage(IkobaAddFormPage):
    """Add-form to add a customer.
    """
    grok.context(IProductsContainer)
    grok.require('waeup.manageProducts')
    grok.name('addproduct')
    form_fields = grok.AutoFields(IProduct)
    label = _('Add product')
    pnav = 1

    @action(_('Create product'), style='primary')
    def addProduct(self, **data):
        product = createObject(u'waeup.Product')
        self.applyData(product, **data)
        self.context.addProduct(product)
        self.flash(_('Product created.'))
        self.redirect(self.url(self.context[product.product_id], 'index'))
        return


class ProductDisplayFormPage(IkobaDisplayFormPage):
    """ Page to display product data
    """
    grok.context(IProduct)
    grok.name('index')
    grok.require('waeup.Public')
    #grok.template('basepage')
    form_fields = grok.AutoFields(IProduct)
    pnav = 1

    @property
    def label(self):
        return self.context.title


class ProductManageFormPage(IkobaEditFormPage):
    """ View to manage product data
    """
    grok.context(IProduct)
    grok.name('manage')
    grok.require('waeup.manageProducts')
    form_fields = grok.AutoFields(IProduct)
    #grok.template('basemanagepage')
    label = _('Manage product')
    pnav = 1